@@ -181,21 +181,23 @@ class PieChartWorkingModes(_DrawingEditorMixin,Drawing):
         self._seriesNames = series_names
         self._seriesData1 = data
         self._seriesData2 = data_trend
-        up = Drawing(3,3).add(Polygon(
-                    strokeColor = DEFAULT_ON_COLOR,
-                    fillColor = DEFAULT_ON_COLOR,
-                    points=[4, 6+(5/2), 4-(5/2), 6-(5/2), 4+(5/2), 6-(5/2), 4, 6+(5/2)] #Structure [(x1,y1),(x2,y2),...]
-                ))
-        down = Drawing(3,3).add(Polygon(
-                    strokeColor = DEFAULT_NEGATIVE_COLOR,
-                    fillColor = DEFAULT_NEGATIVE_COLOR,
-                    points=[4, 6-(5/2), 4+(5/2), 6+(5/2), 4-(5/2), 6+(5/2), 4, 6-(5/2)] 
-                ))
+        # up = Drawing(3,3).add(Polygon(
+        #             strokeColor = DEFAULT_ON_COLOR,
+        #             fillColor = DEFAULT_ON_COLOR,
+        #             points=[4, 6+(5/2), 4-(5/2), 6-(5/2), 4+(5/2), 6-(5/2), 4, 6+(5/2)] #Structure [(x1,y1),(x2,y2),...]
+        #         ))
+        # down = Drawing(3,3).add(Polygon(
+        #             strokeColor = DEFAULT_NEGATIVE_COLOR,
+        #             fillColor = DEFAULT_NEGATIVE_COLOR,
+        #             points=[4, 6-(5/2), 4+(5/2), 6+(5/2), 4-(5/2), 6+(5/2), 4, 6-(5/2)] 
+        #         ))
 
 
         formatter_time = lambda x: '{} h  {} min'.format(int(x), int((x-int(x))*60))
-        formatter_trend = lambda x: DecimalFormatter(places=0, thousandSep=',', decimalSep='.', suffix=' %').format(x) if x != None else x
-        sign_adder = lambda x: '-' if x== None else x if x.startswith('-') else '+{}'.format(x)
+        formatter_trend = lambda x: x if x is None else \
+            DecimalFormatter(places=0, thousandSep=',', decimalSep='.', suffix=' %').format(x) if x <= 100 else \
+                '>100 %'
+        sign_adder = lambda x: '-' if x== None else x if x.startswith('-') or x.startswith('>') else '+{}'.format(x)
         names = list(zip(self._seriesNames,
         map(formatter_time, self._seriesData1),
         map(sign_adder, map(formatter_trend, self._seriesData2))))
