@@ -190,21 +190,22 @@ class SyncroReportWeeklyCreator(FrigelReportCreator):
 
         percentage_hours = int(self.total_operation_hours*100/self.total_operation_hours_prev-100) if self.total_operation_hours_prev != None and self.total_operation_hours_prev > 0 else None
         drawing_triangle = Drawing(3,3) 
-        if percentage_hours and percentage_hours > 0 :
-            drawing_triangle.add(Polygon(
-                    strokeColor = DEFAULT_ON_COLOR,
-                    fillColor = DEFAULT_ON_COLOR,
-                    points=[4, 6+(5/2), 4-(5/2), 6-(5/2), 4+(5/2), 6-(5/2), 4, 6+(5/2)] #Structure [(x1,y1),(x2,y2),...]
-                ))
-        elif percentage_hours:
-            drawing_triangle.add(Polygon(
-                    strokeColor = DEFAULT_NEGATIVE_COLOR,
-                    fillColor = DEFAULT_NEGATIVE_COLOR,
-                    points=[4, 6-(5/2), 4+(5/2), 6+(5/2), 4-(5/2), 6+(5/2), 4, 6-(5/2)] 
-                ))
+        if percentage_hours is not None:
+            if percentage_hours >= 0:
+                drawing_triangle.add(Polygon(
+                        strokeColor = DEFAULT_ON_COLOR,
+                        fillColor = DEFAULT_ON_COLOR,
+                        points=[4, 6+(5/2), 4-(5/2), 6-(5/2), 4+(5/2), 6-(5/2), 4, 6+(5/2)] #Structure [(x1,y1),(x2,y2),...]
+                    ))
+            else:
+                drawing_triangle.add(Polygon(
+                        strokeColor = DEFAULT_NEGATIVE_COLOR,
+                        fillColor = DEFAULT_NEGATIVE_COLOR,
+                        points=[4, 6-(5/2), 4+(5/2), 6+(5/2), 4-(5/2), 6+(5/2), 4, 6-(5/2)] 
+                    ))
         data_table_right = [[table_on_time],
                             [table_on_hours],
-                            [Table(data=[[drawing_triangle, self.translations.getTranslation('{}% (prev week)').format(abs(percentage_hours) if percentage_hours<=100 else '>100')]], colWidths=[10, 2])] if percentage_hours else []]
+                            [Table(data=[[drawing_triangle, self.translations.getTranslation('{}% (prev week)').format(abs(round(percentage_hours)) if percentage_hours<=100 else '>100')]], colWidths=[10, 2])] if percentage_hours is not None else []]
         table_pie_right = Table(data_table_right, colWidths=pie_table_width, rowHeights=[None, None, 35])
         table_pie_right.setStyle([("ALIGN", (0,0), (-1,-1), "LEFT"),
                                   ("FONTSIZE", (0,0), (0,0), 12),
@@ -284,7 +285,7 @@ class SyncroReportWeeklyCreator(FrigelReportCreator):
         text_machine = """<font size="24">
         {}
         </font>
-        """.format(self.translations.getTranslation('Performance Overiew'))
+        """.format(self.translations.getTranslation('Performance Overview'))
         self.addSpacing(DEFAULT_SPACING)
         p_machine = Paragraph(text_machine, self.styles["heading_frigel"])
         self.drawOnCanvas(p_machine, 10 + TA_LEFT, 10)
@@ -320,20 +321,23 @@ class SyncroReportWeeklyCreator(FrigelReportCreator):
         for key in list_key:
             mold_name = Paragraph(key[0:10], styleN)
             list_molds.append([mold_name, '{} h {} min'.format(int(self.molds_info[key]['on']) if type(self.molds_info[key]['on']) == float else self.molds_info[key]['on'], int((self.molds_info[key]['on'] - int(self.molds_info[key]['on']))*60) if type(self.molds_info[key]['on']) == float else self.molds_info[key]['on'] ), 
-                            '{} {}'.format(round(self.molds_info[key]['original_cycle'],2) if type(self.molds_info[key]['original_cycle']) == float else  '-' , 'sec'),
-                            '{} {}'.format(round(self.molds_info[key]['average_cycle'],2) if type(self.molds_info[key]['average_cycle'])== float else self.molds_info[key]['average_cycle'], 'sec'), 
-                            '{} {}'.format(round(100 - self.molds_info[key]['average_cycle']*100/self.molds_info[key]['original_cycle']) if type(self.molds_info[key]['original_cycle']) == float else '-', '%'),
-                            '{} {}'.format(round(self.molds_info[key]['energy_consumption_standard']/self.molds_info[key]['material_produced_standard'],2) if self.molds_info[key]['material_produced_standard']> 0 else '-', 'kWh/kg'),
-                            '{} {}'.format(round(self.molds_info[key]['energy_consumption_syncro']/self.molds_info[key]['material_produced_syncro'],2) if self.molds_info[key]['material_produced_syncro']> 0 else '-', 'kWh/kg')])
+                            '{} {}'.format(round(self.molds_info[key]['original_cycle'],2) if type(self.molds_info[key]['original_cycle']) == float  or type(self.molds_info[key]['original_cycle']) == int else  '-' , 'sec'),
+                            '{} {}'.format(round(self.molds_info[key]['average_cycle'],2) if type(self.molds_info[key]['average_cycle'])== float or self.molds_info[key]['average_cycle'] > 0 else '-', 'sec'), 
+                            '{} {}'.format(round(self.molds_info[key]['average_cycle']*100/self.molds_info[key]['original_cycle']-100,2) if ((type(self.molds_info[key]['original_cycle']) == float  
+                                                                                                                                                or type(self.molds_info[key]['original_cycle'])== int) 
+                                                                                                                                                and self.molds_info[key]['average_cycle'] > 0) else '-', '%'),
+                            '{} {}'.format(round(self.molds_info[key]['energy_consumption_standard']/self.molds_info[key]['material_produced_standard']*1000) if self.molds_info[key]['material_produced_standard']> 0 else '-', 'Wh/kg'),
+                            '{} {}'.format(round(self.molds_info[key]['energy_consumption_syncro']/self.molds_info[key]['material_produced_syncro']*1000) if self.molds_info[key]['material_produced_syncro']> 0 else '-', 'Wh/kg')])
             
         data_performance_overview = list_molds
         table_performance_overview = Table(data_performance_overview, colWidths=table_width)
         for i, row in enumerate(data_performance_overview):
-            standard_time =  row[2].split(' ')[0]
-            syncro_time = row[3].split(' ')[0]
             table_style.append(('LINEABOVE',(0,2),(-1,-1),.5,colors.black)),
-            if i>1 and float(syncro_time)<float(standard_time if standard_time != '-' else 0):
-                table_style.append(('BACKGROUND',(4,i),(4,i), DEFAULT_ON_COLOR))
+            if i>1 :
+                standard_time = float(row[2].split(' ')[0]) if row[2].split(' ')[0] not in ['Cycle', 'Standard', '-'] else 0
+                syncro_time = float(row[3].split(' ')[0]) if row[3].split(' ')[0] not in  ['', 'Syncro', '-'] else 0
+                if syncro_time < standard_time :
+                    table_style.append(('BACKGROUND',(4,i),(4,i), DEFAULT_ON_COLOR))
 
         table_performance_overview.setStyle(table_style)
         _, table_height = table_performance_overview.wrap(0, 0)
